Removes a folio->page->folio conversion for each folio that's involved.
More importantly, removes one of the last few uses of a pagevec.

Signed-off-by: Matthew Wilcox (Oracle) <wi...@infradead.org>
---
 fs/afs/write.c | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/fs/afs/write.c b/fs/afs/write.c
index 18ccb613dff8..6e68c70d0b22 100644
--- a/fs/afs/write.c
+++ b/fs/afs/write.c
@@ -465,7 +465,7 @@ static void afs_extend_writeback(struct address_space 
*mapping,
                                 bool caching,
                                 unsigned int *_len)
 {
-       struct pagevec pvec;
+       struct folio_batch fbatch;
        struct folio *folio;
        unsigned long priv;
        unsigned int psize, filler = 0;
@@ -476,7 +476,7 @@ static void afs_extend_writeback(struct address_space 
*mapping,
        unsigned int i;
 
        XA_STATE(xas, &mapping->i_pages, index);
-       pagevec_init(&pvec);
+       folio_batch_init(&fbatch);
 
        do {
                /* Firstly, we gather up a batch of contiguous dirty pages
@@ -535,7 +535,7 @@ static void afs_extend_writeback(struct address_space 
*mapping,
                                stop = false;
 
                        index += folio_nr_pages(folio);
-                       if (!pagevec_add(&pvec, &folio->page))
+                       if (!folio_batch_add(&fbatch, folio))
                                break;
                        if (stop)
                                break;
@@ -545,14 +545,14 @@ static void afs_extend_writeback(struct address_space 
*mapping,
                        xas_pause(&xas);
                rcu_read_unlock();
 
                /* Now, if we obtained any pages, we can shift them to being
                 * writable and mark them for caching.
                 */
-               if (!pagevec_count(&pvec))
+               if (!folio_batch_count(&fbatch))
                        break;
 
-               for (i = 0; i < pagevec_count(&pvec); i++) {
-                       folio = page_folio(pvec.pages[i]);
+               for (i = 0; i < folio_batch_count(&fbatch); i++) {
+                       folio = fbatch.folios[i];
                        trace_afs_folio_dirty(vnode, 
tracepoint_string("store+"), folio);
 
                        if (!folio_clear_dirty_for_io(folio))
@@ -565,7 +565,7 @@ static void afs_extend_writeback(struct address_space 
*mapping,
                        folio_unlock(folio);
                }
 
-               pagevec_release(&pvec);
+               folio_batch_release(&fbatch);
                cond_resched();
        } while (!stop);
 
@@ -545,14 +545,14 @@ static void afs_extend_writeback(struct address_space 
                rcu_read_unlock();
 
-               /* Now, if we obtained any pages, we can shift them to being
+               /* Now, if we obtained any folios, we can shift them to being
                 * writable and mark them for caching.
                 */
-- 
2.39.2

Reply via email to